package VMOMI::HostInternetScsiHbaDigestType;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
